@@ -241,6 +241,14 @@ def update_kind_schema():
         client=client, newer_cluster_version=same_or_newer_version, schema_definition_file=ocp_openapi_json_file
     )
 
+    # Copy the resources mapping file to fake_kubernetes_client for the fake client to use
+    fake_client_mappings = Path("fake_kubernetes_client/__resources-mappings.json")
+    try:
+        shutil.copy2(RESOURCES_MAPPING_FILE, fake_client_mappings)
+    except (OSError, IOError):
+        # Don't fail the entire process if copy fails
+        pass
+
 
 def convert_camel_case_to_snake_case(name: str) -> str:
     """
@@ -407,7 +415,7 @@ def generate_resource_file_from_dict(
         template_name="class_generator_template.j2",
     )
 
-    output = "# Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md\n\nfrom __future__ import annotations\n"
+    output = "# Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md\n\n"
     formatted_kind_str = convert_camel_case_to_snake_case(name=resource_dict["kind"])
     _file_suffix: str = f"{'_' + output_file_suffix if output_file_suffix else ''}"
 
@@ -442,7 +450,7 @@ def generate_resource_file_from_dict(
             LOGGER.warning(f"{_output_file} already exists, using {temp_output_file}")
             _output_file = temp_output_file
 
-    if _user_code or _user_imports:
+    if _user_code.strip() and _user_imports.strip():
         output += f"{_user_imports}{rendered}{_user_code}"
     else:
         output += rendered
