@@ -1,8 +1,9 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, Optional
+from __future__ import annotations
+from __future__ import annotations
+from typing import Any
 from timeout_sampler import TimeoutSampler, TimeoutWatch
-
 from ocp_resources.utils.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
 
@@ -16,17 +17,17 @@ class Deployment(NamespacedResource):
 
     def __init__(
         self,
-        min_ready_seconds: Optional[int] = None,
-        paused: Optional[bool] = None,
-        progress_deadline_seconds: Optional[int] = None,
-        replicas: Optional[int] = None,
-        revision_history_limit: Optional[int] = None,
-        selector: Optional[Dict[str, Any]] = None,
-        strategy: Optional[Dict[str, Any]] = None,
-        template: Optional[Dict[str, Any]] = None,
+        min_ready_seconds: int | None = None,
+        paused: bool | None = None,
+        progress_deadline_seconds: int | None = None,
+        replicas: int | None = None,
+        revision_history_limit: int | None = None,
+        selector: dict[str, Any] | None = None,
+        strategy: dict[str, Any] | None = None,
+        template: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
             min_ready_seconds (int): Minimum number of seconds for which a newly created pod should be
               ready without any of its container crashing, for it to be
@@ -49,15 +50,15 @@ class Deployment(NamespacedResource):
               pointer to distinguish between explicit zero and not specified.
               Defaults to 10.
 
-            selector (Dict[str, Any]): A label selector is a label query over a set of resources. The result
+            selector (dict[str, Any]): A label selector is a label query over a set of resources. The result
               of matchLabels and matchExpressions are ANDed. An empty label
               selector matches all objects. A null label selector matches no
               objects.
 
-            strategy (Dict[str, Any]): DeploymentStrategy describes how to replace existing pods with new
+            strategy (dict[str, Any]): DeploymentStrategy describes how to replace existing pods with new
               ones.
 
-            template (Dict[str, Any]): PodTemplateSpec describes the data a pod should have when created from
+            template (dict[str, Any]): PodTemplateSpec describes the data a pod should have when created from
               a template
 
         """
@@ -76,10 +77,10 @@ class Deployment(NamespacedResource):
         super().to_dict()
 
         if not self.kind_dict and not self.yaml_file:
-            if not self.selector:
+            if self.selector is None:
                 raise MissingRequiredArgumentError(argument="self.selector")
 
-            if not self.template:
+            if self.template is None:
                 raise MissingRequiredArgumentError(argument="self.template")
 
             self.res["spec"] = {}
@@ -88,22 +89,22 @@ class Deployment(NamespacedResource):
             _spec["selector"] = self.selector
             _spec["template"] = self.template
 
-            if self.min_ready_seconds:
+            if self.min_ready_seconds is not None:
                 _spec["minReadySeconds"] = self.min_ready_seconds
 
             if self.paused is not None:
                 _spec["paused"] = self.paused
 
-            if self.progress_deadline_seconds:
+            if self.progress_deadline_seconds is not None:
                 _spec["progressDeadlineSeconds"] = self.progress_deadline_seconds
 
-            if self.replicas:
+            if self.replicas is not None:
                 _spec["replicas"] = self.replicas
 
-            if self.revision_history_limit:
+            if self.revision_history_limit is not None:
                 _spec["revisionHistoryLimit"] = self.revision_history_limit
 
-            if self.strategy:
+            if self.strategy is not None:
                 _spec["strategy"] = self.strategy
 
     # End of generated code
