@@ -1,6 +1,8 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, List, Optional
+from __future__ import annotations
+from __future__ import annotations
+from typing import Any
 from ocp_resources.resource import Resource
 
 
@@ -11,42 +13,39 @@ class Node(Resource):
 
     api_version: str = Resource.ApiVersion.V1
 
-    class Status(Resource.Status):
-        SCHEDULING_DISABLED = "Ready,SchedulingDisabled"
-
     def __init__(
         self,
-        config_source: Optional[Dict[str, Any]] = None,
-        external_id: Optional[str] = "",
-        pod_cidr: Optional[str] = "",
-        pod_cidrs: Optional[List[Any]] = None,
-        provider_id: Optional[str] = "",
-        taints: Optional[List[Any]] = None,
-        unschedulable: Optional[bool] = None,
+        config_source: dict[str, Any] | None = None,
+        external_id: str | None = None,
+        pod_cidr: str | None = None,
+        pod_cidrs: list[Any] | None = None,
+        provider_id: str | None = None,
+        taints: list[Any] | None = None,
+        unschedulable: bool | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
-            config_source(Dict[str, Any]): NodeConfigSource specifies a source of node configuration. Exactly one
+            config_source (dict[str, Any]): NodeConfigSource specifies a source of node configuration. Exactly one
               subfield (excluding metadata) must be non-nil. This API is
               deprecated since 1.22
 
-            external_id(str): Deprecated. Not all kubelets will set this field. Remove field after
+            external_id (str): Deprecated. Not all kubelets will set this field. Remove field after
               1.13. see: https://issues.k8s.io/61966
 
-            pod_cidr(str): PodCIDR represents the pod IP range assigned to the node.
+            pod_cidr (str): PodCIDR represents the pod IP range assigned to the node.
 
-            pod_cidrs(List[Any]): podCIDRs represents the IP ranges assigned to the node for usage by
+            pod_cidrs (list[Any]): podCIDRs represents the IP ranges assigned to the node for usage by
               Pods on that node. If this field is specified, the 0th entry must
               match the podCIDR field. It may contain at most 1 value for each
               of IPv4 and IPv6.
 
-            provider_id(str): ID of the node assigned by the cloud provider in the format:
+            provider_id (str): ID of the node assigned by the cloud provider in the format:
               <ProviderName>://<ProviderSpecificNodeID>
 
-            taints(List[Any]): If specified, the node's taints.
+            taints (list[Any]): If specified, the node's taints.
 
-            unschedulable(bool): Unschedulable controls node schedulability of new pods. By default,
+            unschedulable (bool): Unschedulable controls node schedulability of new pods. By default,
               node is schedulable. More info:
               https://kubernetes.io/docs/concepts/nodes/node/#manual-node-
               administration
@@ -59,7 +58,7 @@ class Node(Resource):
         self.pod_cidr = pod_cidr
         self.pod_cidrs = pod_cidrs
         self.provider_id = provider_id
-        self._taints = taints
+        self.taints = taints
         self.unschedulable = unschedulable
 
     def to_dict(self) -> None:
@@ -69,27 +68,29 @@ class Node(Resource):
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
-            if self.config_source:
+            if self.config_source is not None:
                 _spec["configSource"] = self.config_source
 
-            if self.external_id:
+            if self.external_id is not None:
                 _spec["externalID"] = self.external_id
 
-            if self.pod_cidr:
+            if self.pod_cidr is not None:
                 _spec["podCIDR"] = self.pod_cidr
 
-            if self.pod_cidrs:
+            if self.pod_cidrs is not None:
                 _spec["podCIDRs"] = self.pod_cidrs
 
-            if self.provider_id:
+            if self.provider_id is not None:
                 _spec["providerID"] = self.provider_id
 
-            if self.taints:
-                _spec["taints"] = self._taints
+            if self.taints is not None:
+                _spec["taints"] = self.taints
 
             if self.unschedulable is not None:
                 _spec["unschedulable"] = self.unschedulable
 
+    # End of generated code
+
     @property
     def kubelet_ready(self):
         return any(
@@ -111,6 +112,5 @@ class Node(Resource):
     def hostname(self):
         return self.labels["kubernetes.io/hostname"]
 
-    @property
-    def taints(self):
+    def get_taints(self):
         return self.instance.get("spec", {}).get("taints")
