@@ -8,10 +8,14 @@ import pytest
 from ocp_resources.exceptions import ResourceTeardownError
 from ocp_resources.namespace import Namespace
 from ocp_resources.pod import Pod
-from ocp_resources.resource import Resource
+from ocp_resources.resource import Resource, ResourceList, NamespacedResourceList
 from ocp_resources.secret import Secret
 from fake_kubernetes_client import FakeDynamicClient
 
+BASE_NAMESPACE_NAME: str = "test-namespace"
+BASE_POD_NAME: str = "test-pod"
+POD_CONTAINERS: list[dict[str, str]] = [{"name": "test-container", "image": "nginx:latest"}]
+
 
 class SecretTestExit(Secret):
     def deploy(self, wait: bool = False):
@@ -28,7 +32,12 @@ def client():
 
 @pytest.fixture(scope="class")
 def namespace(client):
-    return Namespace(client=client, name="test-namespace")
+    return Namespace(client=client, name=BASE_NAMESPACE_NAME)
+
+
+@pytest.fixture(scope="class")
+def namespaces(client):
+    return ResourceList(client=client, resource_class=Namespace, num_resources=3, name=BASE_NAMESPACE_NAME)
 
 
 @pytest.fixture(scope="class")
@@ -36,9 +45,9 @@ def pod(client):
     # Create a test pod for testing purposes
     test_pod = Pod(
         client=client,
-        name="test-pod",
+        name=BASE_POD_NAME,
         namespace="default",
-        containers=[{"name": "test-container", "image": "nginx:latest"}],
+        containers=POD_CONTAINERS,
         annotations={"fake-client.io/ready": "false"},  # Create pod with Ready status FALSE
     )
     deployed_pod = test_pod.deploy()
@@ -47,6 +56,17 @@ def pod(client):
     test_pod.clean_up()
 
 
+@pytest.fixture(scope="class")
+def pods(client, namespaces):
+    return NamespacedResourceList(
+        client=client,
+        resource_class=Pod,
+        namespaces=namespaces,
+        name=BASE_POD_NAME,
+        containers=POD_CONTAINERS,
+    )
+
+
 @pytest.mark.incremental
 class TestResource:
     def test_get(self, client):
@@ -119,6 +139,60 @@ class TestResource:
                 pass
 
 
+@pytest.mark.incremental
+class TestResourceList:
+    def test_resource_list_deploy(self, namespaces):
+        namespaces.deploy()
+        assert namespaces
+
+    def test_resource_list_len(self, namespaces):
+        assert len(namespaces) == 3
+
+    def test_resource_list_name(self, namespaces):
+        for i, ns in enumerate(namespaces.resources, start=1):
+            assert ns.name == f"{BASE_NAMESPACE_NAME}-{i}"
+
+    def test_resource_list_teardown(self, namespaces):
+        namespaces.clean_up(wait=False)
+
+    def test_resource_list_context_manager(self, client):
+        with ResourceList(
+            client=client, resource_class=Namespace, name=BASE_NAMESPACE_NAME, num_resources=3
+        ) as namespaces:
+            assert namespaces
+
+
+@pytest.mark.incremental
+class TestNamespacedResourceList:
+    def test_namespaced_resource_list_deploy(self, client, pods):
+        pods.deploy()
+        assert pods
+
+    def test_resource_list_len(self, namespaces, pods):
+        assert len(pods) == len(namespaces)
+
+    def test_resource_list_name(self, pods):
+        for pod in pods.resources:
+            assert pod.name == BASE_POD_NAME
+
+    def test_namespaced_resource_list_namespace(self, namespaces, pods):
+        for pod, namespace in zip(pods.resources, namespaces):
+            assert pod.namespace == namespace.name
+
+    def test_resource_list_teardown(self, pods):
+        pods.clean_up(wait=False)
+
+    def test_namespaced_resource_list_context_manager(self, client, namespaces):
+        with NamespacedResourceList(
+            client=client,
+            resource_class=Pod,
+            namespaces=namespaces,
+            name=BASE_POD_NAME,
+            containers=POD_CONTAINERS,
+        ) as pods:
+            assert pods
+
+
 @pytest.mark.xfail(reason="Need debug")
 class TestClientProxy:
     @patch.dict(os.environ, {"HTTP_PROXY": "http://env-http-proxy.com"})
