@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.config_map import ConfigMap
 
 
 @pytest.mark.incremental
 class TestConfigMap:
     @pytest.fixture(scope="class")
-    def configmap(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def configmap(self, client):
         return ConfigMap(
-            client=fake_client,
+            client=client,
             name="test-configmap",
             namespace="default",
             data={"key1": "value1"},
